@@ -12,10 +12,7 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
-#include "actiongroup.h"
 #include "appinfo.h"
-#include "application.h"
-#include "applicationcommandline.h"
 #include "asyncinitable.h"
 #include "asyncresult.h"
 #include "bufferedinputstream.h"
@@ -77,7 +74,6 @@
 #include "resolver.h"
 #include "seekable.h"
 #include "settings.h"
-#include "settingsbackend.h"
 #include "socket.h"
 #include "socketaddress.h"
 #include "socketaddressenumerator.h"
@@ -108,8 +104,6 @@ extern "C"
 //Declarations of the *_get_type() functions:
 
 GType g_app_launch_context_get_type(void);
-GType g_application_get_type(void);
-GType g_application_command_line_get_type(void);
 GType g_dbus_auth_observer_get_type(void);
 GType g_buffered_input_stream_get_type(void);
 GType g_buffered_output_stream_get_type(void);
@@ -195,8 +189,6 @@ GQuark g_resolver_error_quark(void);
 //Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:
 
 namespace Gio {  class AppLaunchContext_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gio {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gio {  class ApplicationCommandLine_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio { namespace DBus {  class AuthObserver_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gio {  class BufferedInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -282,8 +274,6 @@ void wrap_init()
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(g_app_launch_context_get_type(), &Gio::AppLaunchContext_Class::wrap_new);
-  Glib::wrap_register(g_application_get_type(), &Gio::Application_Class::wrap_new);
-  Glib::wrap_register(g_application_command_line_get_type(), &Gio::ApplicationCommandLine_Class::wrap_new);
   Glib::wrap_register(g_dbus_auth_observer_get_type(), &Gio::DBus::AuthObserver_Class::wrap_new);
   Glib::wrap_register(g_buffered_input_stream_get_type(), &Gio::BufferedInputStream_Class::wrap_new);
   Glib::wrap_register(g_buffered_output_stream_get_type(), &Gio::BufferedOutputStream_Class::wrap_new);
@@ -360,8 +350,6 @@ void wrap_init()
 
   // Register the gtkmm gtypes:
   Gio::AppLaunchContext::get_type();
-  Gio::Application::get_type();
-  Gio::ApplicationCommandLine::get_type();
   Gio::DBus::AuthObserver::get_type();
   Gio::BufferedInputStream::get_type();
   Gio::BufferedOutputStream::get_type();
